/* 
 * Copyright (C) 2010, Motorola India Private Ltd., 
 * All Rights Reserved 
 * Class name: HTTPConnector.java 
 * Description: This action facilitates SAG to receive the request messages Over HTTP interface,
 * http://localhost:8080/NBIHTTP/http/sendSPR/ 
 * and exposes HTTP Endpoint for CLIP bounce service
 * Used for bulk provisioning feature
 * Modification History: 
 **********************************************************
 * Date          Author		    Comments
 * Sept 24, 2010 Shravan		Created
 **********************************************************
 */
package com.mot.sag.nbi;

import org.apache.log4j.Logger;
import org.jboss.soa.esb.actions.AbstractActionPipelineProcessor;
import org.jboss.soa.esb.actions.ActionProcessingException;
import org.jboss.soa.esb.client.ServiceInvoker;
import org.jboss.soa.esb.helpers.ConfigTree;
import org.jboss.soa.esb.http.HttpRequest;
import org.jboss.soa.esb.listeners.message.MessageDeliverException;
import org.jboss.soa.esb.message.Message;

import com.mot.sag.logger.MPSLogger;
import com.mot.sag.nbi.util.SAGNBIConstants;

public class HTTPConnector extends AbstractActionPipelineProcessor {
	protected ConfigTree _config;
	private static Logger logger = MPSLogger.getLogger(HTTPConnector.class);
	private static final String CLIPBOUNCE_SERVICE="clipbounce";
	private static final String CLIPBOUNCE_SERVICECAT="netopaaa";
	private static final String CLIPBOUNCE_URL="/http/bounceClip";
	private static final String NBIHTTP_URL="/http/sendSPR";
	public HTTPConnector(ConfigTree config) {
		_config = config;
	}
	public void processException(Message message, java.lang.Throwable e)
	{
		logger.error("Exception in HTTPConnector action", e);
	}

	public void processSuccess(Message message)
	{
		logger.info("HTTP request successfully dispatched");
	}
	@Override
	public Message process(Message message) throws ActionProcessingException {
		logger.info("message received in HTTPConnector :\n");
		if(logger.isDebugEnabled()){
			logger.debug("message received in HTTPConnector :\n" + message.getBody().get());
		}	
		String serviceName = null;
		String serviceCategory = null;
		try{
			HttpRequest request = HttpRequest.getRequest(message);
			/*
		List<HttpHeader> list = request.getHeaders();
		for(HttpHeader str:list){
			System.out.println(str.getName()+"-" + str.getValue());
		}		
		System.out.println("PathInfo=" + request.getPathInfo());
		System.out.println("requestURI=" + request.getRequestURI());
		System.out.println("RemoteUser=" + request.getRemoteUser());
		System.out.println("requestPath=" + request.getRequestPath());
		//System.out.println("customProperty=" + request.);
			 */		
			String requestPath = request.getRequestPath();
			if(requestPath.contains(CLIPBOUNCE_URL)){

				serviceCategory=CLIPBOUNCE_SERVICECAT;
				serviceName=CLIPBOUNCE_SERVICE;
				logger.debug("forwarding clipbounce request to " + serviceCategory+":" + serviceName);
			}
			else if(requestPath.contains(NBIHTTP_URL)){
				message.getProperties().setProperty(SAGNBIConstants.NBI_MODE, SAGNBIConstants.NBI_MODE_HTTP);
				//dispatching to validation service after setting nbi specific properties
				serviceCategory=SAGNBIConstants.CORE_SERVICECAT_VALIDATION;
				serviceName=SAGNBIConstants.CORE_SERVICE_VALIDATION;
				//logger.debug("forwarding SPRequestMessage to " + serviceCategory+":" + serviceName);
			}

			new ServiceInvoker(serviceCategory,serviceName ).deliverAsync(message);
		} catch (MessageDeliverException e) {

			throw new ActionProcessingException(e);
		}
		return null;
	}
}
